#!/bin/sh
# the next line restarts using wish\
exec wish "$0" "$@" 

if {![info exists vTcl(sourcing)]} {

    # Provoke name search
    catch {package require bogus-package-name}
    set packageNames [package names]

    package require BWidget
    switch $tcl_platform(platform) {
	windows {
	}
	default {
	    option add *ScrolledWindow.size 14
	}
    }
    
    package require Tk
    switch $tcl_platform(platform) {
	windows {
            option add *Button.padY 0
	}
	default {
            option add *Scrollbar.width 10
            option add *Scrollbar.highlightThickness 0
            option add *Scrollbar.elementBorderWidth 2
            option add *Scrollbar.borderWidth 2
	}
    }
    
}

#############################################################################
# Visual Tcl v1.60 Project
#




#############################################################################
## vTcl Code to Load Stock Images


if {![info exist vTcl(sourcing)]} {
#############################################################################
## Procedure:  vTcl:rename

proc ::vTcl:rename {name} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    regsub -all "\\." $name "_" ret
    regsub -all "\\-" $ret "_" ret
    regsub -all " " $ret "_" ret
    regsub -all "/" $ret "__" ret
    regsub -all "::" $ret "__" ret

    return [string tolower $ret]
}

#############################################################################
## Procedure:  vTcl:image:create_new_image

proc ::vTcl:image:create_new_image {filename {description {no description}} {type {}} {data {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl env

    # Does the image already exist?
    if {[info exists vTcl(images,files)]} {
        if {[lsearch -exact $vTcl(images,files) $filename] > -1} { return }
    }

    if {![info exists vTcl(sourcing)] && [string length $data] > 0} {
        set object [image create  [vTcl:image:get_creation_type $filename]  -data $data]
    } else {
        # Wait a minute... Does the file actually exist?
        if {! [file exists $filename] } {
            # Try current directory
            set script [file dirname [info script]]
            set filename [file join $script [file tail $filename] ]
        }

        if {![file exists $filename]} {
            set description "file not found!"
            set object [image create photo -data [vTcl:image:broken_image] ]
        } else {
            set object [image create  [vTcl:image:get_creation_type $filename]  -file $filename]
        }
    }

    set reference [vTcl:rename $filename]

    set vTcl(images,$reference,image)       $object
    set vTcl(images,$reference,description) $description
    set vTcl(images,$reference,type)        $type
    set vTcl(images,filename,$object)       $filename

    lappend vTcl(images,files) $filename
    lappend vTcl(images,$type) $object

    # return image name in case caller might want it
    return $object
}

#############################################################################
## Procedure:  vTcl:image:get_image

proc ::vTcl:image:get_image {filename} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    set reference [vTcl:rename $filename]

    # Let's do some checking first
    if {![info exists ::vTcl(images,$reference,image)]} {
        # Well, the path may be wrong; in that case check
        # only the filename instead, without the path.

        set imageTail [file tail $filename]

        foreach oneFile $::vTcl(images,files) {
            if {[file tail $oneFile] == $imageTail} {
                set reference [vTcl:rename $oneFile]
                break
            }
        }
    }
    return $::vTcl(images,$reference,image)
}

#############################################################################
## Procedure:  vTcl:image:get_creation_type

proc ::vTcl:image:get_creation_type {filename} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    switch [string tolower [file extension $filename]] {
        .ppm -
        .jpg -
        .bmp -
        .gif    {return photo}
        .xbm    {return bitmap}
        default {return photo}
    }
}

#############################################################################
## Procedure:  vTcl:image:broken_image

proc ::vTcl:image:broken_image {} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    return {
        R0lGODdhFAAUAPcAAAAAAIAAAACAAICAAAAAgIAAgACAgMDAwICAgP8AAAD/
        AP//AAAA//8A/wD//////wAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA
        AAAAAAAAAAAAAAAAAAAAACwAAAAAFAAUAAAIhAAPCBxIsKDBgwgPAljIUOBC
        BAkBPJg4UeBEBBAVPkCI4EHGghIHChAwsKNHgyEPCFBA0mFDkBtVjiz4AADK
        mAds0tRJMCVBBkAl8hwYMsFPBwyE3jzQwKhAoASUwmTagCjDmksbVDWIderC
        g1174gQ71CHFigfOhrXKUGfbrwnjyp0bEAA7
    }
}

foreach img {


            } {
    eval set _file [lindex $img 0]
    vTcl:image:create_new_image\
        $_file [lindex $img 1] [lindex $img 2] [lindex $img 3]
}

}
#############################################################################
## vTcl Code to Load User Images

catch {package require Img}

foreach img {

        {{[file join / home ag src q graph images open.gif]} {user image} user {
R0lGODlhEAAPAPIEAAAAAICAAP//AICAgP///////wAAAAAAACH5BAEAAAUA
LAAAAAAQAA8AAAONWFVVhVVVVVhVVYVVVVVYAFCFVVVVWFUFhVVQUFgFAIVV
VVVYAFWAQgIACAAFgFAFJEhCQoJQVVU4ICSEQkJQWFU1gCQkAAgAAIBQA0Io
EBGBERFQOEACgRERERhQNYACEQAYEQGFVQMQGBERgQFVVTgAAIAAAFBYVTWD
MzMzOFVVhVVVVVhVVYVVVVUJADs=}}
        {{[file join / home ag src q graph images save.gif]} {user image} user {
R0lGODlhEAAPAPIDAAAAAICAAICAgP///////wAAAAAAAAAAACH5BAEAAAQA
LAAAAAAQAA8AAAONSEREhEREREhERIQAAAAIAACAQEQQCDQ0hENAQEgEAYM0
NDQIAESEEEBDODQEgUBEEAhDQ4M0EEBIBAGEQ0NDCAFEhBABAAgAEIFARBAY
ERGBERFASAQRgAAAAAgBRIQQASAIQASBQEQQGCAggEQQQEgEEYAgAEQIAUSE
BAAACAAAgEBEREhERIREREQJADs=}}
        {{[file join / home ag src q graph images cut.gif]} {user image} user {
R0lGODlhEAAPAPEDAAAAAAAAgICAgP///yH5BAEAAAMALAAAAAAQAA8AAAKI
3Lhx4saJGzdu3Lhx4saJGzdu3Lhx4caFGzdu3LhxoUaFGzdu3LhxYcaEGzdu
3LhxYsaIGzdu3LhxY8KMGzdu3Lhxo0KNGzdu3LhxY8KMGzdu3LhxY8aEGTdu
3LgxYcaMCjdu3LhQY8aMCzdu3LhwY8aICzdu3LhwYsaFGTdu3Lgx4caNGzdu
BQA7}}
        {{[file join / home ag src q graph images copy.gif]} {user image} user {
R0lGODlhEAAPAPIDAAAAAAAAgICAgP///////wAAAAAAAAAAACH5BAEAAAQA
LAAAAAAQAA8AAAONSBERgUFEREhEJIEzMxFIRESERBIzOBMDhERERCgxAIMR
EREYRCSBMzMSODMTgEQSAwgAMYMzMUAoMTODEgMwGBEhgQMAEDgzM4MTEjM4
IzGAAAATKBERgREzMzgzIYIiIhI4AACAE0RESCQxgzMzE0hERIQSEREYEUGE
REQiKCIigkREREhERIREREQJADs=}}
        {{[file join / home ag src q graph images paste.gif]} {user image} user {
R0lGODlhEAAPAPIFAAAAAAAAgICAAP//AICAgP///////wAAACH5BAEAAAYA
LAAAAAAQAA8AAAONaGZmhgAAZmhmZoYAADA4AACAZgZiKDAAg2BiYEhgBIVV
VQVIAkaAQgAACABAhmAEJmhiFoEREWBIICaGQlFVWBFGgCYmRhhVVYEVBGIo
JhSFABURSGBigkZRVVhVQYBiYkIYBQCAFUYACAAQhVVVFWhGRIREEREYEWGG
ZmZGSEREhGZmZmhmZoZmZmYJADs=}}
        {{[file join / home ag src q graph images cancel.gif]} {user image} user {
R0lGODlhEQAPAPECAAAAAIAAAP///wAAACH5BAEAAAIALAAAAAARAA8AAAKQ
lChRokSJEiVKlChRokSJEiVKlChRYUSJEiUmlChRYsKIEiUmjChRosSEESUm
jChRokSJCSMmjChRokSJEhMmjChRokSJEiUmjChRokSJEiUmTBhRokSJEiUm
jJgwokSJEiUmjCgxYUSJEiUmjChRYsKIEiUqjChRosSEEiVKlChRokSJEiVK
lChRokSJEiWqADs=}}
        {{[file join / home ag src q graph images ok.gif]} {user image} user {
R0lGODlhEQAPAPECAAAAAACAAP///wAAACH5BAEAAAIALAAAAAARAA8AAAKQ
lChRokSJEiVKlChRokSJEiVKlChRokSJEiUmlChRokSJEiUqjChRokSJEiUq
jChRokSJEiVKTChRokSJCSVKTChRokSJCiNKVBhRokSJEhVGVBhRokSJEiUm
lJhQokSJEiVKTJhQokSJEiVKVJgwokSJEiVKlKgwokSJEiVKlChRokSJEiVK
lChRokSJEiWqADs=}}
        {{[file join / home ag src q graph images new.gif]} {user image} user {
R0lGODlhEAAPAPECAAAAAICAgP///////yH5BAEAAAMALAAAAAAQAA8AAAKI
3Lhx48aNGzdu3DgQIECAGzdu3DhQokSBGDdu3BhQokSBAjdu3BhQokSBADFu
3BhQokSJGzFu3BhQokSJEjFu3BhQokSJEjFu3BhQokSJEjFu3BhQokSJEjFu
3BhQokSJEjFu3BhQokSJEjFu3BgQIECAADFu3JgwYcKEGTdu3Lhx48aNGzdu
BQA7}}
        {{[file join / home ag src q graph images print.gif]} {user image} user {
R0lGODlhEAAPAPIEAAAAAIAAAICAAICAgP///////wAAAAAAACH5BAEAAAUA
LAAAAAAQAA8AAAONWFVVhVVVVVhVVYVVBQAIAACAVVVVCEREhEQEVVhVBYQA
AEAIVVWFBURESEQEhVVVBUgAAIAEAFBYBUSEREQEODBQgAAAAAgAA4MAICVY
UlKCBQMDCAAAgAAAAAgzAIIlJTUYUQKDAFBSKCUlhVIAAAgAAIAAAAAIAFWA
AAAACAAAgFVVVVhVVYVVVVUJADs=}}

            } {
    eval set _file [lindex $img 0]
    vTcl:image:create_new_image\
        $_file [lindex $img 1] [lindex $img 2] [lindex $img 3]
}

#################################
# VTCL LIBRARY PROCEDURES
#

if {![info exists vTcl(sourcing)]} {
#############################################################################
## Library Procedure:  Window

proc ::Window {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global vTcl
    set cmd     [lindex $args 0]
    set name    [lindex $args 1]
    set newname [lindex $args 2]
    set rest    [lrange $args 3 end]
    if {$name == "" || $cmd == ""} { return }
    if {$newname == ""} { set newname $name }
    if {$name == "."} { wm withdraw $name; return }
    set exists [winfo exists $newname]
    switch $cmd {
        show {
            if {$exists} {
                wm deiconify $newname
            } elseif {[info procs vTclWindow$name] != ""} {
                eval "vTclWindow$name $newname $rest"
            }
            if {[winfo exists $newname] && [wm state $newname] == "normal"} {
                vTcl:FireEvent $newname <<Show>>
            }
        }
        hide    {
            if {$exists} {
                wm withdraw $newname
                vTcl:FireEvent $newname <<Hide>>
                return}
        }
        iconify { if $exists {wm iconify $newname; return} }
        destroy { if $exists {destroy $newname; return} }
    }
}
#############################################################################
## Library Procedure:  vTcl:DefineAlias

proc ::vTcl:DefineAlias {target alias widgetProc top_or_alias cmdalias} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    global widget
    set widget($alias) $target
    set widget(rev,$target) $alias
    if {$cmdalias} {
        interp alias {} $alias {} $widgetProc $target
    }
    if {$top_or_alias != ""} {
        set widget($top_or_alias,$alias) $target
        if {$cmdalias} {
            interp alias {} $top_or_alias.$alias {} $widgetProc $target
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:DoCmdOption

proc ::vTcl:DoCmdOption {target cmd} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## menus are considered toplevel windows
    set parent $target
    while {[winfo class $parent] == "Menu"} {
        set parent [winfo parent $parent]
    }

    regsub -all {\%widget} $cmd $target cmd
    regsub -all {\%top} $cmd [winfo toplevel $parent] cmd

    uplevel #0 [list eval $cmd]
}
#############################################################################
## Library Procedure:  vTcl:FireEvent

proc ::vTcl:FireEvent {target event {params {}}} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    ## The window may have disappeared
    if {![winfo exists $target]} return
    ## Process each binding tag, looking for the event
    foreach bindtag [bindtags $target] {
        set tag_events [bind $bindtag]
        set stop_processing 0
        foreach tag_event $tag_events {
            if {$tag_event == $event} {
                set bind_code [bind $bindtag $tag_event]
                foreach rep "\{%W $target\} $params" {
                    regsub -all [lindex $rep 0] $bind_code [lindex $rep 1] bind_code
                }
                set result [catch {uplevel #0 $bind_code} errortext]
                if {$result == 3} {
                    ## break exception, stop processing
                    set stop_processing 1
                } elseif {$result != 0} {
                    bgerror $errortext
                }
                break
            }
        }
        if {$stop_processing} {break}
    }
}
#############################################################################
## Library Procedure:  vTcl:Toplevel:WidgetProc

proc ::vTcl:Toplevel:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    set command [lindex $args 0]
    set args [lrange $args 1 end]
    switch -- $command {
        "setvar" {
            set varname [lindex $args 0]
            set value [lindex $args 1]
            if {$value == ""} {
                return [set ::${w}::${varname}]
            } else {
                return [set ::${w}::${varname} $value]
            }
        }
        "hide" - "Hide" - "show" - "Show" {
            Window [string tolower $command] $w
        }
        "ShowModal" {
            Window show $w
            raise $w
            grab $w
            tkwait window $w
            grab release $w
        }
        default {
            uplevel $w $command $args
        }
    }
}
#############################################################################
## Library Procedure:  vTcl:WidgetProc

proc ::vTcl:WidgetProc {w args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    if {[llength $args] == 0} {
        ## If no arguments, returns the path the alias points to
        return $w
    }
    ## The first argument is a switch, they must be doing a configure.
    if {[string index $args 0] == "-"} {
        set command configure
        ## There's only one argument, must be a cget.
        if {[llength $args] == 1} {
            set command cget
        }
    } else {
        set command [lindex $args 0]
        set args [lrange $args 1 end]
    }
    uplevel $w $command $args
}
#############################################################################
## Library Procedure:  vTcl:toplevel

proc ::vTcl:toplevel {args} {
    ## This procedure may be used free of restrictions.
    ##    Exception added by Christian Gavin on 08/08/02.
    ## Other packages and widget toolkits have different licensing requirements.
    ##    Please read their license agreements for details.

    uplevel #0 eval toplevel $args
    set target [lindex $args 0]
    namespace eval ::$target {}
}
}


if {[info exists vTcl(sourcing)]} {

proc vTcl:project:info {} {
    set base .top81
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.fra83 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_3_0 $base.fra83
    namespace eval ::widgets::$site_3_0.fra82 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_4_0 $site_3_0.fra82
    namespace eval ::widgets::$site_4_0.but83 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but84 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but85 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but86 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.fra87 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_4_0 $site_3_0.fra87
    namespace eval ::widgets::$site_4_0.but88 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but89 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_4_0.but90 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.com82 {
        array set save {-command 1 -entrybg 1 -height 1 -modifycmd 1 -takefocus 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.ent92 {
        array set save {-background 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_3_0.but82 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.but81 {
        array set save {-_tooltip 1 -command 1 -image 1 -overrelief 1 -relief 1 -text 1}
    }
    namespace eval ::widgets::$base.fra85 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_3_0 $base.fra85
    namespace eval ::widgets::$site_3_0.can89 {
        array set save {-background 1 -borderwidth 1 -closeenough 1 -height 1 -relief 1 -width 1 -xscrollcommand 1 -yscrollcommand 1}
    }
    namespace eval ::widgets::$site_3_0.scr90 {
        array set save {-command 1}
    }
    namespace eval ::widgets::$site_3_0.scr91 {
        array set save {-command 1 -orient 1}
    }
    namespace eval ::widgets::$base.fra86 {
        array set save {-borderwidth 1 -width 1}
    }
    set site_3_0 $base.fra86
    namespace eval ::widgets::$site_3_0.lab92 {
        array set save {-anchor 1 -font 1 -justify 1 -relief 1 -textvariable 1}
    }
    namespace eval ::widgets::$site_3_0.lab93 {
        array set save {-font 1 -relief 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.lab81 {
        array set save {-relief 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$base.m82 {
        array set save {-font 1 -relief 1 -tearoff 1}
    }
    set site_3_0 $base.m82
    namespace eval ::widgets::$site_3_0.men83 {
        array set save {-font 1 -tearoff 1}
    }
    set site_3_0 $base.m82
    namespace eval ::widgets::$site_3_0.men81 {
        array set save {-font 1 -tearoff 1}
    }
    set site_3_0 $base.m82
    namespace eval ::widgets::$site_3_0.men85 {
        array set save {-font 1 -tearoff 1}
    }
    set site_3_0 $base.m82
    namespace eval ::widgets::$site_3_0.help {
        array set save {-font 1 -tearoff 1}
    }
    set base .top83
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.not84 {
        array set save {-height 1 -width 1}
        namespace eval subOptions {
            array set save {-text 1}
        }
    }
    set site_4_0 [$base.not84 getframe page1]
    namespace eval ::widgets::$site_4_0 {
        array set save {-borderwidth 1}
    }
    set site_4_0 $site_4_0
    namespace eval ::widgets::$site_4_0.lab85 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent86 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab82 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent83 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab83 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent84 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab86 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent87 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab88 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent89 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab90 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent91 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab92 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent93 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab94 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent95 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab81 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab84 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab87 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.che89 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.che90 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.che91 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.che92 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.che93 {
        array set save {-text 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.lab95 {
        array set save {}
    }
    namespace eval ::widgets::$site_4_0.lab89 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab91 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent92 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    set site_4_1 [$base.not84 getframe page2]
    namespace eval ::widgets::$site_4_1 {
        array set save {-borderwidth 1}
    }
    set site_4_0 $site_4_1
    namespace eval ::widgets::$site_4_0.lab85 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent86 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab87 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent88 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab89 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent90 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab91 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent92 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab93 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent94 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab95 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent96 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab97 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.ent98 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab99 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab101 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab103 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab105 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.fra82 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.lab81 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.lab83 {
        array set save {-text 1}
    }
    namespace eval ::widgets::$site_4_0.but81 {
        array set save {-command 1 -padx 1}
    }
    namespace eval ::widgets::$site_4_0.but82 {
        array set save {-command 1 -padx 1}
    }
    namespace eval ::widgets::$site_4_0.but83 {
        array set save {-command 1 -padx 1}
    }
    namespace eval ::widgets::$site_4_0.but84 {
        array set save {-command 1 -padx 1}
    }
    namespace eval ::widgets::$site_4_0.but85 {
        array set save {-command 1 -padx 1}
    }
    namespace eval ::widgets::$site_4_0.but86 {
        array set save {-command 1 -padx 1}
    }
    namespace eval ::widgets::$base.fra96 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    namespace eval ::widgets::$base.fra97 {
        array set save {-borderwidth 1 -height 1 -width 1}
    }
    set site_3_0 $base.fra97
    namespace eval ::widgets::$site_3_0.but81 {
        array set save {-command 1 -takefocus 1 -text 1 -underline 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.but82 {
        array set save {-command 1 -text 1 -underline 1 -width 1}
    }
    set base .top84
    namespace eval ::widgets::$base {
        set set,origin 0
        set set,size 1
        set runvisible 1
    }
    namespace eval ::widgets::$base.cpd87 {
        array set save {-foreground 1 -highlightcolor 1 -text 1}
    }
    set site_3_0 $base.cpd87
    namespace eval ::widgets::$site_3_0.fra150 {
        array set save {-height 1 -width 1}
    }
    set site_4_0 $site_3_0.fra150
    namespace eval ::widgets::$site_4_0.cpd151 {
        array set save {-font 1 -text 1 -underline 1}
    }
    namespace eval ::widgets::$site_4_0.cpd152 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$base.lab125 {
        array set save {-foreground 1 -highlightcolor 1 -text 1}
    }
    set site_3_0 $base.lab125
    namespace eval ::widgets::$site_3_0.cpd126 {
        array set save {-height 1 -width 1}
    }
    set site_4_0 $site_3_0.cpd126
    namespace eval ::widgets::$site_4_0.cpd122 {
        array set save {-font 1 -text 1 -underline 1}
    }
    namespace eval ::widgets::$site_4_0.cpd123 {
        array set save {-editable 1 -entrybg 1 -modifycmd 1 -takefocus 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd124 {
        array set save {-font 1 -text 1 -underline 1 -variable 1}
    }
    namespace eval ::widgets::$site_4_0.cpd83 {
        array set save {-font 1 -text 1 -underline 1 -variable 1}
    }
    namespace eval ::widgets::$site_3_0.fra127 {
        array set save {-height 1 -width 1}
    }
    set site_4_0 $site_3_0.fra127
    namespace eval ::widgets::$site_4_0.cpd128 {
        array set save {-font 1 -text 1 -underline 1}
    }
    namespace eval ::widgets::$site_4_0.cpd129 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd130 {
        array set save {-font 1 -text 1 -underline 1}
    }
    namespace eval ::widgets::$site_4_0.cpd131 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd132 {
        array set save {-font 1 -text 1 -underline 1}
    }
    namespace eval ::widgets::$site_4_0.cpd133 {
        array set save {-background 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_4_0.cpd134 {
        array set save {-font 1 -text 1 -underline 1}
    }
    namespace eval ::widgets::$site_4_0.cpd135 {
        array set save {-editable 1 -entrybg 1 -modifycmd 1 -takefocus 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$base.lab136 {
        array set save {-foreground 1 -highlightcolor 1 -text 1}
    }
    set site_3_0 $base.lab136
    namespace eval ::widgets::$site_3_0.che137 {
        array set save {-command 1 -font 1 -text 1 -underline 1 -variable 1}
    }
    namespace eval ::widgets::$site_3_0.spi138 {
        array set save {-entrybg 1 -entryfg 1 -range 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.lab139 {
        array set save {-font 1 -text 1}
    }
    namespace eval ::widgets::$site_3_0.che140 {
        array set save {-command 1 -font 1 -text 1 -underline 1 -variable 1}
    }
    namespace eval ::widgets::$site_3_0.spi141 {
        array set save {-entrybg 1 -entryfg 1 -range 1 -takefocus 1 -text 1 -textvariable 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.lab142 {
        array set save {-font 1 -text 1}
    }
    namespace eval ::widgets::$base.cpd145 {
        array set save {-borderwidth 1 -height 1 -relief 1 -width 1}
    }
    set site_3_0 $base.cpd145
    namespace eval ::widgets::$site_3_0.but93 {
        array set save {-command 1 -text 1 -underline 1 -width 1}
    }
    namespace eval ::widgets::$site_3_0.but94 {
        array set save {-command 1 -text 1 -underline 1 -width 1}
    }
    namespace eval ::widgets_bindings {
        set tagslist {_TopLevel all _vTclBalloon TopLevel1}
    }
    namespace eval ::vTcl::modules::main {
        set procs {
            init
            main
            autoscroll
        }
        set compounds {
        }
    }
}
}

#################################
# USER DEFINED PROCEDURES
#
#############################################################################
## Procedure:  main

proc ::main {argc argv} {}
#############################################################################
## Procedure:  autoscroll

proc ::autoscroll {widget x y} {
if { $y >= [winfo height $widget] } {
  $widget yview scroll 1 units
} elseif { $y < 0 } {
  $widget yview scroll -1 units
}
if { $x >= [winfo width $widget] } {
  $widget xview scroll 1 units
} elseif { $x < 0 } {
  $widget xview scroll -1 units
}
global scrollid
set scrollid [after 50 [list autoscroll $widget $x $y]]
}

#############################################################################
## Initialization Procedure:  init

proc ::init {argc argv} {
global scrollid
set scrollid ""
if {[info command q] == {}} then { proc q { args } { } }
if {[info command graphed] == {}} then { proc graphed { } { return graphed } }
option add *Dialog.msg.font {Helvetica 12}
option add *fra83*Button.borderWidth 1
}

init $argc $argv

#################################
# VTCL GENERATED GUI PROCEDURES
#

proc vTclWindow. {base} {
    if {$base == ""} {
        set base .
    }
    ###################
    # CREATING WIDGETS
    ###################
    wm focusmodel $top passive
    wm geometry $top 1x1+0+0; update
    wm maxsize $top 1137 834
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm withdraw $top
    wm title $top "vtcl.tcl"
    bindtags $top "$top Vtcl.tcl all"
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    ###################
    # SETTING GEOMETRY
    ###################

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top81 {base} {
    if {$base == ""} {
        set base .top81
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -menu "$top.m82" -highlightcolor black 
    wm focusmodel $top passive
    wm geometry $top 609x422; update
    wm maxsize $top 1137 834
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 1 1
    wm deiconify $top
    wm title $top "graphed"
    vTcl:DefineAlias "$top" "Toplevel1" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel TopLevel1"
    bind $top <Alt-Key-r> {
        # TODO: your event handler here
q [graphed]::reload_config_cb
    }
    bind $top <Alt-Key-s> {
        # TODO: your event handler here
q [graphed]::save_config_cb
    }
    bind $top <Control-Key-KP_Add> {
        # TODO: your event handler here
q [graphed]::zoom_in_cb
    }
    bind $top <Control-Key-KP_Subtract> {
        # TODO: your event handler here
q [graphed]::zoom_out_cb
    }
    bind $top <Control-Key-a> {
        # TODO: your event handler here
q [graphed]::select_all_cb
    }
    bind $top <Control-Key-c> {
        # TODO: your event handler here
q [graphed]::copy_cb
    }
    bind $top <Control-Key-e> {
        # TODO: your event handler here
q [graphed]::invert_all_cb
    }
    bind $top <Control-Key-g> {
        # TODO: your event handler here
q [graphed]::toggle_grid_cb
    }
    bind $top <Control-Key-i> {
        # TODO: your event handler here
q [graphed]::toggle_snap_cb
    }
    bind $top <Control-Key-minus> {
        # TODO: your event handler here
q [graphed]::zoom_out_cb
    }
    bind $top <Control-Key-n> {
        # TODO: your event handler here
q [graphed]::new_cb
    }
    bind $top <Control-Key-o> {
        # TODO: your event handler here
q [graphed]::open_cb
    }
    bind $top <Control-Key-p> {
        # TODO: your event handler here
q [graphed]::print_cb
    }
    bind $top <Control-Key-plus> {
        # TODO: your event handler here
q [graphed]::zoom_in_cb
    }
    bind $top <Control-Key-q> {
        # TODO: your event handler here
q [graphed]::quit_cb
    }
    bind $top <Control-Key-r> {
        # TODO: your event handler here
q [graphed]::redraw_cb
    }
    bind $top <Control-Key-s> {
        # TODO: your event handler here
q [graphed]::save_cb
    }
    bind $top <Control-Key-t> {
        # TODO: your event handler here
q [graphed]::extend_cb
    }
    bind $top <Control-Key-v> {
        # TODO: your event handler here
q [graphed]::paste_cb
    }
    bind $top <Control-Key-x> {
        # TODO: your event handler here
q [graphed]::cut_cb
    }
    bind $top <Control-Key-z> {
        # TODO: your event handler here
q [graphed]::undo_cb
    }
    bind $top <Key-Escape> {
        # TODO: your event handler here
q cancel_select_cb
    }
    bind $top <Shift-Key-Delete> {
        # TODO: your event handler here
q [graphed]::delete_cb
    }
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    frame $top.fra83 \
        -borderwidth 2 -relief groove -height 34 -width 125 
    vTcl:DefineAlias "$top.fra83" "Frame3" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra83
    frame $site_3_0.fra82 \
        -borderwidth 2 -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.fra82" "Frame4" vTcl:WidgetProc "Toplevel1" 1
    set site_4_0 $site_3_0.fra82
    button $site_4_0.but83 \
        -command {q [graphed]::new_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images new.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but83" "NewButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but83 "$site_4_0.but83 Button $top all _vTclBalloon"
    bind $site_4_0.but83 <<SetBalloon>> {
        set ::vTcl::balloon::%W {New}
    }
    button $site_4_0.but84 \
        -command {q [graphed]::open_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images open.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but84" "OpenButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but84 "$site_4_0.but84 Button $top all _vTclBalloon"
    bind $site_4_0.but84 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Open}
    }
    button $site_4_0.but85 \
        -command {q [graphed]::save_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images save.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but85" "SaveButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but85 "$site_4_0.but85 Button $top all _vTclBalloon"
    bind $site_4_0.but85 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Save}
    }
    button $site_4_0.but86 \
        -command {q [graphed]::print_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images print.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but86" "PrintButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but86 "$site_4_0.but86 Button $top all _vTclBalloon"
    bind $site_4_0.but86 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Print}
    }
    pack $site_4_0.but83 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.but84 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.but85 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.but86 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    frame $site_3_0.fra87 \
        -borderwidth 2 -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.fra87" "Frame5" vTcl:WidgetProc "Toplevel1" 1
    set site_4_0 $site_3_0.fra87
    button $site_4_0.but88 \
        -command {q [graphed]::cut_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images cut.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but88" "CutButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but88 "$site_4_0.but88 Button $top all _vTclBalloon"
    bind $site_4_0.but88 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Cut}
    }
    button $site_4_0.but89 \
        -command {q [graphed]::copy_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images copy.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but89" "CopyButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but89 "$site_4_0.but89 Button $top all _vTclBalloon"
    bind $site_4_0.but89 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Copy}
    }
    button $site_4_0.but90 \
        -command {q [graphed]::paste_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images paste.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_4_0.but90" "PasteButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_4_0.but90 "$site_4_0.but90 Button $top all _vTclBalloon"
    bind $site_4_0.but90 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Paste}
    }
    pack $site_4_0.but88 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.but89 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.but90 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    ComboBox $site_3_0.com82 \
        -command {q [graphed]::zoom_entry_cb} -entrybg white -height 10 \
        -modifycmd {q [graphed]::zoom_cb} -takefocus 1 -textvariable zoom \
        -width 5 
    vTcl:DefineAlias "$site_3_0.com82" "ComboBox1" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.com82 "$site_3_0.com82 BwComboBox $top all"
    entry $site_3_0.ent92 \
        -background white -textvariable entry 
    vTcl:DefineAlias "$site_3_0.ent92" "Entry" vTcl:WidgetProc "Toplevel1" 1
    bind $site_3_0.ent92 <Key-Escape> {
        # TODO: your event handler here
q [graphed]::cancel_cb
    }
    bind $site_3_0.ent92 <Key-Return> {
        # TODO: your event handler here
q [graphed]::enter_cb
    }
    button $site_3_0.but82 \
        -command {q [graphed]::enter_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images ok.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_3_0.but82" "OkButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but82 "$site_3_0.but82 Button $top all _vTclBalloon"
    bind $site_3_0.but82 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Accept}
    }
    button $site_3_0.but81 \
        -command {q [graphed]::cancel_cb} \
        -image [vTcl:image:get_image [file join / home ag src q graph images cancel.gif]] \
        -overrelief raised -relief flat -text button 
    vTcl:DefineAlias "$site_3_0.but81" "CancelButton" vTcl:WidgetProc "Toplevel1" 1
    bindtags $site_3_0.but81 "$site_3_0.but81 Button $top all _vTclBalloon"
    bind $site_3_0.but81 <<SetBalloon>> {
        set ::vTcl::balloon::%W {Cancel}
    }
    pack $site_3_0.fra82 \
        -in $site_3_0 -anchor center -expand 0 -fill none -padx 2 -side left 
    pack $site_3_0.fra87 \
        -in $site_3_0 -anchor center -expand 0 -fill none -padx 2 -side left 
    pack $site_3_0.com82 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.ent92 \
        -in $site_3_0 -anchor center -expand 1 -fill x -side left 
    pack $site_3_0.but82 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but81 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    frame $top.fra85 \
        -borderwidth 2 -height 75 -width 125 
    vTcl:DefineAlias "$top.fra85" "Frame1" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra85
    canvas $site_3_0.can89 \
        -background #ffffff -borderwidth 2 -closeenough 1.0 -height 207 \
        -relief sunken -width 295 -xscrollcommand "$site_3_0.scr91 set" \
        -yscrollcommand "$site_3_0.scr90 set" 
    vTcl:DefineAlias "$site_3_0.can89" "Canvas" vTcl:WidgetProc "Toplevel1" 1
    bind $site_3_0.can89 <B1-Enter> {
        # TODO: your event handler here
after cancel $scrollid
    }
    bind $site_3_0.can89 <B1-Leave> {
        # TODO: your event handler here
autoscroll %W %x %y
    }
    bind $site_3_0.can89 <Button-1> {
        # TODO: your event handler here
set scrollid ""
q [graphed]::start_select_cb (%x,%y)
    }
    bind $site_3_0.can89 <Button-2> {
        # TODO: your event handler here
q [graphed]::start_select2_cb (%x,%y)
    }
    bind $site_3_0.can89 <Button-3> {
        # TODO: your event handler here
q [graphed]::select3_cb (%X,%Y) (%x,%y)
    }
    bind $site_3_0.can89 <ButtonRelease-1> {
        # TODO: your event handler here
if { $scrollid != "" } {
  after cancel $scrollid
}
q [graphed]::end_select_cb (%x,%y)
    }
    bind $site_3_0.can89 <ButtonRelease-2> {
        # TODO: your event handler here
q cancel_select_cb
    }
    bind $site_3_0.can89 <Control-Button-1> {
        # TODO: your event handler here
set scrollid ""
q [graphed]::start_ctrl_select_cb (%x,%y)
    }
    bind $site_3_0.can89 <Control-ButtonRelease-1> {
        # TODO: your event handler here
if { $scrollid != "" } {
  after cancel $scrollid
}
q [graphed]::end_ctrl_select_cb (%x,%y)
    }
    bind $site_3_0.can89 <Motion> {
        # TODO: your event handler here
q [graphed]::motion_cb (%x,%y)
    }
    bind $site_3_0.can89 <Shift-Button-1> {
        # TODO: your event handler here
set scrollid ""
q [graphed]::start_shift_select_cb (%x,%y)
    }
    bind $site_3_0.can89 <Shift-ButtonRelease-1> {
        # TODO: your event handler here
if { $scrollid != "" } {
  after cancel $scrollid
}
q [graphed]::end_shift_select_cb (%x,%y)
    }
    scrollbar $site_3_0.scr90 \
        -command "$site_3_0.can89 yview" 
    vTcl:DefineAlias "$site_3_0.scr90" "Scrollbar1" vTcl:WidgetProc "Toplevel1" 1
    scrollbar $site_3_0.scr91 \
        -command "$site_3_0.can89 xview" -orient horizontal 
    vTcl:DefineAlias "$site_3_0.scr91" "Scrollbar2" vTcl:WidgetProc "Toplevel1" 1
    grid $site_3_0.can89 \
        -in $site_3_0 -column 0 -row 0 -columnspan 1 -rowspan 1 -sticky nesw 
    grid $site_3_0.scr90 \
        -in $site_3_0 -column 1 -row 0 -columnspan 1 -rowspan 1 -sticky ns 
    grid $site_3_0.scr91 \
        -in $site_3_0 -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky ew 
    frame $top.fra86 \
        -borderwidth 2 -width 125 
    vTcl:DefineAlias "$top.fra86" "Frame2" vTcl:WidgetProc "Toplevel1" 1
    set site_3_0 $top.fra86
    label $site_3_0.lab92 \
        -anchor w -font {Helvetica -12} -justify left -relief sunken \
        -textvariable msg 
    vTcl:DefineAlias "$site_3_0.lab92" "Label1" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.lab93 \
        -font {Helvetica -12} -relief sunken -textvariable status -width 9 
    vTcl:DefineAlias "$site_3_0.lab93" "Label2" vTcl:WidgetProc "Toplevel1" 1
    label $site_3_0.lab81 \
        -relief sunken -text {} -textvariable mode -width 2 
    vTcl:DefineAlias "$site_3_0.lab81" "Label3" vTcl:WidgetProc "Toplevel1" 1
    pack $site_3_0.lab92 \
        -in $site_3_0 -anchor w -expand 1 -fill x -side left 
    pack $site_3_0.lab93 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side right 
    pack $site_3_0.lab81 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side right 
    menu $top.m82 \
        -font {Helvetica -12} -relief flat -tearoff 1 
    $top.m82 add cascade \
        -menu "$top.m82.men83" -label File -underline 0 
    set site_3_0 $top.m82
    menu $site_3_0.men83 \
        -font {Helvetica -12} -tearoff 0 
    vTcl:DefineAlias "$site_3_0.men83" "FileMenu" vTcl:WidgetProc "" 1
    $site_3_0.men83 add command \
        -accelerator Ctrl+N \
        -command {# TODO: Your menu handler here
q [graphed]::new_cb} \
        -label New -underline 0 
    $site_3_0.men83 add command \
        -accelerator Ctrl+O \
        -command {# TODO: Your menu handler here
q [graphed]::open_cb} \
        -label Open... -underline 0 
    $site_3_0.men83 add command \
        -accelerator Ctrl+S \
        -command {# TODO: Your menu handler here
q [graphed]::save_cb} \
        -label Save -underline 0 
    $site_3_0.men83 add command \
        -command {# TODO: Your menu handler here
q [graphed]::save_as_cb} \
        -label {Save as...} -underline 5 
    $site_3_0.men83 add command \
        -accelerator Ctrl+P \
        -command {# TODO: Your menu handler here
q [graphed]::print_cb} \
        -label Print -underline 0 
    $site_3_0.men83 add command \
        -command {# TODO: Your menu handler here
q [graphed]::print_file_cb} \
        -label {Print to file...} -underline 9 
    $site_3_0.men83 add command \
        -command {# TODO: Your menu handler here
q [graphed]::print_setup_cb} \
        -label {Print setup...} -underline 8 
    $site_3_0.men83 add separator \
        
    $site_3_0.men83 add command \
        -accelerator Ctrl+Q \
        -command {# TODO: Your menu handler here
q [graphed]::quit_cb} \
        -label Quit -underline 0 
    $top.m82 add cascade \
        -menu "$top.m82.men81" -label Edit -underline 0 
    set site_3_0 $top.m82
    menu $site_3_0.men81 \
        -font {Helvetica -12} -tearoff 0 
    vTcl:DefineAlias "$site_3_0.men81" "EditMenu" vTcl:WidgetProc "" 1
    $site_3_0.men81 add command \
        -accelerator Ctrl+Z \
        -command {# TODO: Your menu handler here
q [graphed]::undo_cb} \
        -label Undo -underline 0 
    $site_3_0.men81 add separator \
        
    $site_3_0.men81 add command \
        -accelerator Ctrl+X \
        -command {# TODO: Your menu handler here
q [graphed]::cut_cb} \
        -label Cut -underline 2 
    $site_3_0.men81 add command \
        -accelerator Ctrl+C \
        -command {# TODO: Your menu handler here
q [graphed]::copy_cb} \
        -label Copy -underline 0 
    $site_3_0.men81 add command \
        -accelerator Ctrl+V \
        -command {# TODO: Your menu handler here
q [graphed]::paste_cb} \
        -label Paste -underline 0 
    $site_3_0.men81 add separator \
        
    $site_3_0.men81 add command \
        -accelerator Shift+Del \
        -command {# TODO: Your menu handler here
q [graphed]::delete_cb} \
        -label Delete -underline 0 
    $site_3_0.men81 add separator \
        
    $site_3_0.men81 add command \
        -accelerator Ctrl+A \
        -command {# TODO: Your menu handler here
q [graphed]::select_all_cb} \
        -label {Select all} -underline 7 
    $site_3_0.men81 add command \
        -accelerator Ctrl+E \
        -command {# TODO: Your menu handler here
q [graphed]::invert_all_cb} \
        -label {Invert all} -underline 3 
    $site_3_0.men81 add command \
        -accelerator Ctrl+T \
        -command {# TODO: Your menu handler here
q [graphed]::extend_cb} \
        -label Extend -underline 2 
    $top.m82 add cascade \
        -menu "$top.m82.men85" -label View -underline 0 
    set site_3_0 $top.m82
    menu $site_3_0.men85 \
        -font {Helvetica -12} -tearoff 0 
    vTcl:DefineAlias "$site_3_0.men85" "ViewMenu" vTcl:WidgetProc "" 1
    $site_3_0.men85 add checkbutton \
        -variable grid -accelerator Ctrl+G \
        -command {# TODO: Your menu handler here
q [graphed]::grid_cb} \
        -label Grid -underline 0 
    $site_3_0.men85 add checkbutton \
        -variable snap -accelerator Ctrl+I \
        -command {# TODO: Your menu handler here
q [graphed]::snap_cb} \
        -label {Snap to grid} -underline 10 
    $site_3_0.men85 add checkbutton \
        -variable digraph_mode \
        -command {# TODO: Your menu handler here
q [graphed]::digraph_mode_cb} \
        -label {Digraph mode} -underline 8 
    $site_3_0.men85 add separator \
        
    $site_3_0.men85 add command \
        -accelerator Ctrl+R \
        -command {# TODO: Your menu handler here
q [graphed]::redraw_cb} \
        -label Redraw -underline 0 
    $site_3_0.men85 add separator \
        
    $site_3_0.men85 add command \
        -accelerator Ctrl++ \
        -command {# TODO: Your menu handler here
q [graphed]::zoom_in_cb} \
        -label {Zoom in} -underline 5 
    $site_3_0.men85 add command \
        -accelerator Ctrl+- \
        -command {# TODO: Your menu handler here
q [graphed]::zoom_out_cb} \
        -label {Zoom out} -underline 5 
    $site_3_0.men85 add separator \
        
    $site_3_0.men85 add command \
        -accelerator Alt+S \
        -command {# TODO: Your menu handler here
q [graphed]::save_config_cb} \
        -label {Save config} -underline 0 
    $site_3_0.men85 add command \
        -accelerator Alt+R \
        -command {# TODO: Your menu handler here
q [graphed]::reload_config_cb} \
        -label {Reload config} -underline 2 
    $site_3_0.men85 add command \
        -command {# TODO: Your menu handler here
q [graphed]::defaults_cb} \
        -label Defaults -underline 0 
    $site_3_0.men85 add command \
        -command {# TODO: Your menu handler here
q [graphed]::config_cb} \
        -label Configure... -underline 0 
    $top.m82 add cascade \
        -menu "$top.m82.help" -label Help -underline 0 
    set site_3_0 $top.m82
    menu $site_3_0.help \
        -font {Helvetica -12} -tearoff 0 
    vTcl:DefineAlias "$site_3_0.help" "HelpMenu" vTcl:WidgetProc "" 1
    $site_3_0.help add command \
        -command {# TODO: Your menu handler here
q [graphed]::about_cb} \
        -label About -underline 0 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $top.fra83 \
        -in $top -anchor center -expand 0 -fill x -side top 
    pack $top.fra85 \
        -in $top -anchor w -expand 1 -fill both -side top 
    grid columnconf $top.fra85 0 -weight 1
    grid rowconf $top.fra85 0 -weight 1
    pack $top.fra86 \
        -in $top -anchor w -expand 0 -fill x -side top 

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top83 {base} {
    if {$base == ""} {
        set base .top83
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -highlightcolor black 
    wm withdraw $top
    wm focusmodel $top passive
    wm geometry $top 461x318; update
    wm maxsize $top 1137 834
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 0 0
    wm title $top "Configure"
    vTcl:DefineAlias "$top" "Toplevel3" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    bind $top <Alt-Key-c> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(ConfigureCancelButton)
    }
    bind $top <Alt-Key-o> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(ConfigureOkButton)
    }
    bind $top <Key-Escape> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(ConfigureCancelButton)
    }
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    NoteBook $top.not84 \
        -height 209 -width 311 
    vTcl:DefineAlias "$top.not84" "NoteBook1" vTcl:WidgetProc "Toplevel3" 1
    $top.not84 insert end page1 \
        -text {Display Settings} 
    $top.not84 insert end page2 \
        -text Appearance 
    set site_4_0 [$top.not84 getframe page1]
    label $site_4_0.lab85 \
        -text X1 
    vTcl:DefineAlias "$site_4_0.lab85" "Label1" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent86 \
        -background white -textvariable x1 -width 6 
    vTcl:DefineAlias "$site_4_0.ent86" "Entry1" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab82 \
        -text Y1 
    vTcl:DefineAlias "$site_4_0.lab82" "Label2" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent83 \
        -background white -textvariable y1 -width 6 
    vTcl:DefineAlias "$site_4_0.ent83" "Entry2" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab83 \
        -text X2 
    vTcl:DefineAlias "$site_4_0.lab83" "Label3" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent84 \
        -background white -textvariable x2 -width 6 
    vTcl:DefineAlias "$site_4_0.ent84" "Entry3" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab86 \
        -text Y2 
    vTcl:DefineAlias "$site_4_0.lab86" "Label4" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent87 \
        -background white -textvariable y2 -width 6 
    vTcl:DefineAlias "$site_4_0.ent87" "Entry4" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab88 \
        -text RX 
    vTcl:DefineAlias "$site_4_0.lab88" "Label5" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent89 \
        -background white -textvariable xres -width 6 
    vTcl:DefineAlias "$site_4_0.ent89" "Entry5" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab90 \
        -text RY 
    vTcl:DefineAlias "$site_4_0.lab90" "Label6" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent91 \
        -background white -textvariable yres -width 6 
    vTcl:DefineAlias "$site_4_0.ent91" "Entry6" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab92 \
        -text DX 
    vTcl:DefineAlias "$site_4_0.lab92" "Label7" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent93 \
        -background white -textvariable xgrid -width 6 
    vTcl:DefineAlias "$site_4_0.ent93" "Entry7" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab94 \
        -text DY 
    vTcl:DefineAlias "$site_4_0.lab94" "Label8" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent95 \
        -background white -textvariable ygrid -width 6 
    vTcl:DefineAlias "$site_4_0.ent95" "Entry8" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab81 \
        -text Range 
    vTcl:DefineAlias "$site_4_0.lab81" "Label9" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab84 \
        -text {Resolution   } 
    vTcl:DefineAlias "$site_4_0.lab84" "Label10" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab87 \
        -text {Grid spacing  } 
    vTcl:DefineAlias "$site_4_0.lab87" "Label11" vTcl:WidgetProc "Toplevel3" 1
    checkbutton $site_4_0.che89 \
        -text {Show node numbers} -variable nodenum 
    vTcl:DefineAlias "$site_4_0.che89" "Checkbutton1" vTcl:WidgetProc "Toplevel3" 1
    checkbutton $site_4_0.che90 \
        -text {Show node labels} -variable nodelbl 
    vTcl:DefineAlias "$site_4_0.che90" "Checkbutton2" vTcl:WidgetProc "Toplevel3" 1
    checkbutton $site_4_0.che91 \
        -text {Show edge labels} -variable edgelbl 
    vTcl:DefineAlias "$site_4_0.che91" "Checkbutton3" vTcl:WidgetProc "Toplevel3" 1
    checkbutton $site_4_0.che92 \
        -text {Show grid} -variable grid 
    vTcl:DefineAlias "$site_4_0.che92" "Checkbutton4" vTcl:WidgetProc "Toplevel3" 1
    checkbutton $site_4_0.che93 \
        -text {Snap to grid} -variable snap 
    vTcl:DefineAlias "$site_4_0.che93" "Checkbutton5" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab95
    vTcl:DefineAlias "$site_4_0.lab95" "Label23" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab89 \
        -text {Zoom factor } 
    vTcl:DefineAlias "$site_4_0.lab89" "Label24" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_0.lab91 \
        -text ZF 
    vTcl:DefineAlias "$site_4_0.lab91" "Label25" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_0.ent92 \
        -background white -textvariable zfact -width 6 
    vTcl:DefineAlias "$site_4_0.ent92" "Entry20" vTcl:WidgetProc "Toplevel3" 1
    grid $site_4_0.lab85 \
        -in $site_4_0 -column 1 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent86 \
        -in $site_4_0 -column 2 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab82 \
        -in $site_4_0 -column 3 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent83 \
        -in $site_4_0 -column 4 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab83 \
        -in $site_4_0 -column 1 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent84 \
        -in $site_4_0 -column 2 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab86 \
        -in $site_4_0 -column 3 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent87 \
        -in $site_4_0 -column 4 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab88 \
        -in $site_4_0 -column 1 -row 2 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent89 \
        -in $site_4_0 -column 2 -row 2 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab90 \
        -in $site_4_0 -column 3 -row 2 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent91 \
        -in $site_4_0 -column 4 -row 2 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab92 \
        -in $site_4_0 -column 1 -row 3 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent93 \
        -in $site_4_0 -column 2 -row 3 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab94 \
        -in $site_4_0 -column 3 -row 3 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent95 \
        -in $site_4_0 -column 4 -row 3 -columnspan 1 -rowspan 1 
    grid $site_4_0.lab81 \
        -in $site_4_0 -column 0 -row 0 -columnspan 1 -rowspan 2 -sticky w 
    grid $site_4_0.lab84 \
        -in $site_4_0 -column 0 -row 2 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.lab87 \
        -in $site_4_0 -column 0 -row 3 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.che89 \
        -in $site_4_0 -column 6 -row 0 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.che90 \
        -in $site_4_0 -column 6 -row 1 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.che91 \
        -in $site_4_0 -column 6 -row 2 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.che92 \
        -in $site_4_0 -column 6 -row 3 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.che93 \
        -in $site_4_0 -column 6 -row 4 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.lab95 \
        -in $site_4_0 -column 5 -row 0 -columnspan 1 -rowspan 1 -padx 10 
    grid $site_4_0.lab89 \
        -in $site_4_0 -column 0 -row 4 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_4_0.lab91 \
        -in $site_4_0 -column 1 -row 4 -columnspan 1 -rowspan 1 
    grid $site_4_0.ent92 \
        -in $site_4_0 -column 2 -row 4 -columnspan 1 -rowspan 1 
    set site_4_1 [$top.not84 getframe page2]
    label $site_4_1.lab85 \
        -text {Node radius:} 
    vTcl:DefineAlias "$site_4_1.lab85" "Label12" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent86 \
        -background white -textvariable nodewd -width 6 
    vTcl:DefineAlias "$site_4_1.ent86" "Entry9" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab87 \
        -text {Label offset:} 
    vTcl:DefineAlias "$site_4_1.lab87" "Label13" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent88 \
        -background white -textvariable nlbloffs -width 6 
    vTcl:DefineAlias "$site_4_1.ent88" "Entry10" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab89 \
        -text Placement: 
    vTcl:DefineAlias "$site_4_1.lab89" "Label14" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent90 \
        -background white -textvariable nlbldir -width 6 
    vTcl:DefineAlias "$site_4_1.ent90" "Entry11" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab91 \
        -text {Edge width:} 
    vTcl:DefineAlias "$site_4_1.lab91" "Label15" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent92 \
        -background white -textvariable edgewd -width 6 
    vTcl:DefineAlias "$site_4_1.ent92" "Entry12" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab93 \
        -text {Label offset:} 
    vTcl:DefineAlias "$site_4_1.lab93" "Label16" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent94 \
        -background white -textvariable elbloffs -width 6 
    vTcl:DefineAlias "$site_4_1.ent94" "Entry13" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab95 \
        -text Placement: 
    vTcl:DefineAlias "$site_4_1.lab95" "Label17" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent96 \
        -background white -textvariable elbldir -width 6 
    vTcl:DefineAlias "$site_4_1.ent96" "Entry14" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab97 \
        -text {Loop placement:} 
    vTcl:DefineAlias "$site_4_1.lab97" "Label18" vTcl:WidgetProc "Toplevel3" 1
    entry $site_4_1.ent98 \
        -background white -textvariable loopdir -width 6 
    vTcl:DefineAlias "$site_4_1.ent98" "Entry15" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab99 \
        -text {Node outline:} 
    vTcl:DefineAlias "$site_4_1.lab99" "Label19" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab101 \
        -text {Fill color:} 
    vTcl:DefineAlias "$site_4_1.lab101" "Label20" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab103 \
        -text {Mark color:} 
    vTcl:DefineAlias "$site_4_1.lab103" "Label21" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab105 \
        -text {Edge color:} 
    vTcl:DefineAlias "$site_4_1.lab105" "Label22" vTcl:WidgetProc "Toplevel3" 1
    frame $site_4_1.fra82 \
        -borderwidth 2 -relief sunken -height 2 -width 391 
    vTcl:DefineAlias "$site_4_1.fra82" "Frame1" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab81 \
        -text {Label color:} 
    vTcl:DefineAlias "$site_4_1.lab81" "Label26" vTcl:WidgetProc "Toplevel3" 1
    label $site_4_1.lab83 \
        -text {Grid color:} 
    vTcl:DefineAlias "$site_4_1.lab83" "Label27" vTcl:WidgetProc "Toplevel3" 1
    button $site_4_1.but81 \
        -command {q [graphed]::update_cb [graphed]::outlcol_cb} -padx 10 
    vTcl:DefineAlias "$site_4_1.but81" "OutlButton" vTcl:WidgetProc "Toplevel3" 1
    button $site_4_1.but82 \
        -command {q [graphed]::update_cb [graphed]::fillcol_cb} -padx 10 
    vTcl:DefineAlias "$site_4_1.but82" "FillButton" vTcl:WidgetProc "Toplevel3" 1
    button $site_4_1.but83 \
        -command {q [graphed]::update_cb [graphed]::markcol_cb} -padx 10 
    vTcl:DefineAlias "$site_4_1.but83" "MarkButton" vTcl:WidgetProc "Toplevel3" 1
    button $site_4_1.but84 \
        -command {q [graphed]::update_cb [graphed]::edgecol_cb} -padx 10 
    vTcl:DefineAlias "$site_4_1.but84" "EdgeButton" vTcl:WidgetProc "Toplevel3" 1
    button $site_4_1.but85 \
        -command {q [graphed]::update_cb [graphed]::lblcol_cb} -padx 10 
    vTcl:DefineAlias "$site_4_1.but85" "LblButton" vTcl:WidgetProc "Toplevel3" 1
    button $site_4_1.but86 \
        -command {q [graphed]::update_cb [graphed]::gridcol_cb} -padx 10 
    vTcl:DefineAlias "$site_4_1.but86" "GridButton" vTcl:WidgetProc "Toplevel3" 1
    grid $site_4_1.lab85 \
        -in $site_4_1 -column 0 -row 0 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.ent86 \
        -in $site_4_1 -column 1 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab87 \
        -in $site_4_1 -column 2 -row 0 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.ent88 \
        -in $site_4_1 -column 3 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab89 \
        -in $site_4_1 -column 4 -row 0 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.ent90 \
        -in $site_4_1 -column 5 -row 0 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab91 \
        -in $site_4_1 -column 0 -row 1 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.ent92 \
        -in $site_4_1 -column 1 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab93 \
        -in $site_4_1 -column 2 -row 1 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.ent94 \
        -in $site_4_1 -column 3 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab95 \
        -in $site_4_1 -column 4 -row 1 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.ent96 \
        -in $site_4_1 -column 5 -row 1 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab97 \
        -in $site_4_1 -column 3 -row 2 -columnspan 2 -rowspan 1 -sticky e 
    grid $site_4_1.ent98 \
        -in $site_4_1 -column 5 -row 2 -columnspan 1 -rowspan 1 
    grid $site_4_1.lab99 \
        -in $site_4_1 -column 0 -row 4 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.lab101 \
        -in $site_4_1 -column 2 -row 4 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.lab103 \
        -in $site_4_1 -column 4 -row 4 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.lab105 \
        -in $site_4_1 -column 0 -row 5 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.fra82 \
        -in $site_4_1 -column 0 -row 3 -columnspan 6 -rowspan 1 -pady 10 
    grid $site_4_1.lab81 \
        -in $site_4_1 -column 2 -row 5 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.lab83 \
        -in $site_4_1 -column 4 -row 5 -columnspan 1 -rowspan 1 -sticky e 
    grid $site_4_1.but81 \
        -in $site_4_1 -column 1 -row 4 -columnspan 1 -rowspan 1 
    grid $site_4_1.but82 \
        -in $site_4_1 -column 3 -row 4 -columnspan 1 -rowspan 1 
    grid $site_4_1.but83 \
        -in $site_4_1 -column 5 -row 4 -columnspan 1 -rowspan 1 
    grid $site_4_1.but84 \
        -in $site_4_1 -column 1 -row 5 -columnspan 1 -rowspan 1 
    grid $site_4_1.but85 \
        -in $site_4_1 -column 3 -row 5 -columnspan 1 -rowspan 1 
    grid $site_4_1.but86 \
        -in $site_4_1 -column 5 -row 5 -columnspan 1 -rowspan 1 
    $top.not84 raise page1
    frame $top.fra96 \
        -borderwidth 2 -relief sunken -height 2 -width 125 
    vTcl:DefineAlias "$top.fra96" "Frame2" vTcl:WidgetProc "Toplevel3" 1
    frame $top.fra97 \
        -borderwidth 2 -height 75 -width 125 
    vTcl:DefineAlias "$top.fra97" "Frame3" vTcl:WidgetProc "Toplevel3" 1
    set site_3_0 $top.fra97
    button $site_3_0.but81 \
        -command {q [graphed]::convert_cb [graphed]::config_ok_cb} \
        -takefocus 1 -text OK -underline 0 -width 6 
    vTcl:DefineAlias "$site_3_0.but81" "ConfigureOkButton" vTcl:WidgetProc "Toplevel3" 1
    button $site_3_0.but82 \
        -command {q [graphed]::config_cancel_cb} -text Cancel -underline 0 \
        -width 6 
    vTcl:DefineAlias "$site_3_0.but82" "ConfigureCancelButton" vTcl:WidgetProc "Toplevel3" 1
    pack $site_3_0.but81 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but82 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side right 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $top.not84 \
        -in $top -anchor center -expand 0 -fill both -padx 15 -pady 10 \
        -side top 
    pack $top.fra96 \
        -in $top -anchor center -expand 0 -fill both -side top 
    pack $top.fra97 \
        -in $top -anchor center -expand 0 -fill x -padx 15 -pady 10 \
        -side bottom 
    grid columnconf $top.fra97 1 -weight 1
    grid columnconf $top.fra97 2 -weight 1
    grid columnconf $top.fra97 3 -weight 1

    vTcl:FireEvent $base <<Ready>>
}

proc vTclWindow.top84 {base} {
    if {$base == ""} {
        set base .top84
    }
    if {[winfo exists $base]} {
        wm deiconify $base; return
    }
    set top $base
    ###################
    # CREATING WIDGETS
    ###################
    vTcl:toplevel $top -class Toplevel \
        -highlightcolor black 
    wm withdraw $top
    wm focusmodel $top passive
    wm geometry $top 494x306; update
    wm maxsize $top 1137 834
    wm minsize $top 1 1
    wm overrideredirect $top 0
    wm resizable $top 0 0
    wm title $top "Print setup"
    vTcl:DefineAlias "$top" "Toplevel2" vTcl:Toplevel:WidgetProc "" 1
    bindtags $top "$top Toplevel all _TopLevel"
    bind $top <Alt-Key-l> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(LandscapeButton)
focus $widget(LandscapeButton)
    }
    bind $top <Alt-Key-c> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(PrintSetupCancelButton)
    }
    bind $top <Alt-Key-h> {
        # TODO: your event handler here
focus $widget(HeightEntry)
    }
    bind $top <Alt-Key-k> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(PrintCropmarksButton)
focus $widget(PrintCropmarksButton)
    }
    bind $top <Alt-Key-m> {
        # TODO: your event handler here
focus $widget(MarginEntry)
    }
    bind $top <Alt-Key-o> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(PrintSetupOkButton)
    }
    bind $top <Alt-Key-p> {
        # TODO: your event handler here
focus $widget(PrintCmdEntry)
    }
    bind $top <Alt-Key-s> {
        # TODO: your event handler here
focus $widget(PaperSizeBox)
    }
    bind $top <Alt-Key-u> {
        # TODO: your event handler here
focus $widget(UnitBox)
    }
    bind $top <Alt-Key-w> {
        # TODO: your event handler here
focus $widget(WidthEntry)
    }
    bind $top <Alt-Key-x> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(ScaleXButton)
if { $scalex } {
  focus $widget(XPagesBox)
} else {
  focus $widget(ScaleXButton)
}
    }
    bind $top <Alt-Key-y> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(ScaleYButton)
if { $scaley } {
  focus $widget(YPagesBox)
} else {
  focus $widget(ScaleYButton)
}
    }
    bind $top <Key-Escape> {
        # TODO: your event handler here
tk::ButtonInvoke $widget(PrintSetupCancelButton)
    }
    vTcl:FireEvent $top <<Create>>
    wm protocol $top WM_DELETE_WINDOW "vTcl:FireEvent $top <<DeleteWindow>>"

    labelframe $top.cpd87 \
        -foreground black -text {Print options} -highlightcolor black 
    vTcl:DefineAlias "$top.cpd87" "Labelframe1" vTcl:WidgetProc "Toplevel2" 1
    set site_3_0 $top.cpd87
    frame $site_3_0.fra150 \
        -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.fra150" "Frame6" vTcl:WidgetProc "Toplevel2" 1
    set site_4_0 $site_3_0.fra150
    label $site_4_0.cpd151 \
        -font {Helvetica -12} -text {Print command:} -underline 0 
    vTcl:DefineAlias "$site_4_0.cpd151" "Label1" vTcl:WidgetProc "Toplevel2" 1
    entry $site_4_0.cpd152 \
        -background white -textvariable print_cmd -width 48 
    vTcl:DefineAlias "$site_4_0.cpd152" "PrintCmdEntry" vTcl:WidgetProc "Toplevel2" 1
    pack $site_4_0.cpd151 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.cpd152 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 5 -side left 
    pack $site_3_0.fra150 \
        -in $site_3_0 -anchor center -expand 0 -fill x -padx 10 -side top 
    labelframe $top.lab125 \
        -foreground black -text {Page setup} -highlightcolor black 
    vTcl:DefineAlias "$top.lab125" "Labelframe4" vTcl:WidgetProc "Toplevel2" 1
    set site_3_0 $top.lab125
    frame $site_3_0.cpd126 \
        -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.cpd126" "Frame2" vTcl:WidgetProc "Toplevel2" 1
    set site_4_0 $site_3_0.cpd126
    label $site_4_0.cpd122 \
        -font {Helvetica -12} -text {Paper size:} -underline 6 
    vTcl:DefineAlias "$site_4_0.cpd122" "Label2" vTcl:WidgetProc "Toplevel2" 1
    ComboBox $site_4_0.cpd123 \
        -editable 0 -entrybg white \
        -modifycmd {q [graphed]::update_cb [graphed]::paper_cb} -takefocus 1 \
        -textvariable paper -width 12 
    vTcl:DefineAlias "$site_4_0.cpd123" "PaperSizeBox" vTcl:WidgetProc "Toplevel2" 1
    bindtags $site_4_0.cpd123 "$site_4_0.cpd123 BwComboBox $top all"
    checkbutton $site_4_0.cpd124 \
        -font {Helvetica -12} -text Landscape -underline 0 \
        -variable landscape 
    vTcl:DefineAlias "$site_4_0.cpd124" "LandscapeButton" vTcl:WidgetProc "Toplevel2" 1
    checkbutton $site_4_0.cpd83 \
        -font {Helvetica -12} -text {Cropmarks/page labels} -underline 7 \
        -variable print_cropmarks 
    vTcl:DefineAlias "$site_4_0.cpd83" "PrintCropmarksButton" vTcl:WidgetProc "Toplevel2" 1
    pack $site_4_0.cpd122 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.cpd123 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 10 -side left 
    pack $site_4_0.cpd124 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 10 -side left 
    pack $site_4_0.cpd83 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side top 
    frame $site_3_0.fra127 \
        -height 75 -width 125 
    vTcl:DefineAlias "$site_3_0.fra127" "Frame1" vTcl:WidgetProc "Toplevel2" 1
    set site_4_0 $site_3_0.fra127
    label $site_4_0.cpd128 \
        -font {Helvetica -12} -text Width: -underline 0 
    vTcl:DefineAlias "$site_4_0.cpd128" "Label4" vTcl:WidgetProc "Toplevel2" 1
    entry $site_4_0.cpd129 \
        -background white -textvariable width -width 8 
    vTcl:DefineAlias "$site_4_0.cpd129" "WidthEntry" vTcl:WidgetProc "Toplevel2" 1
    bind $site_4_0.cpd129 <Key> {
        # TODO: your event handler here
q [graphed]::update_cb [graphed]::paper_check_cb
    }
    label $site_4_0.cpd130 \
        -font {Helvetica -12} -text Height: -underline 0 
    vTcl:DefineAlias "$site_4_0.cpd130" "Label5" vTcl:WidgetProc "Toplevel2" 1
    entry $site_4_0.cpd131 \
        -background white -textvariable height -width 8 
    vTcl:DefineAlias "$site_4_0.cpd131" "HeightEntry" vTcl:WidgetProc "Toplevel2" 1
    bind $site_4_0.cpd131 <Key> {
        # TODO: your event handler here
q [graphed]::update_cb [graphed]::paper_check_cb
    }
    label $site_4_0.cpd132 \
        -font {Helvetica -12} -text Margin: -underline 0 
    vTcl:DefineAlias "$site_4_0.cpd132" "Label3" vTcl:WidgetProc "Toplevel2" 1
    entry $site_4_0.cpd133 \
        -background white -textvariable margin -width 8 
    vTcl:DefineAlias "$site_4_0.cpd133" "MarginEntry" vTcl:WidgetProc "Toplevel2" 1
    label $site_4_0.cpd134 \
        -font {Helvetica -12} -text Unit: -underline 0 
    vTcl:DefineAlias "$site_4_0.cpd134" "Label6" vTcl:WidgetProc "Toplevel2" 1
    ComboBox $site_4_0.cpd135 \
        -editable 0 -entrybg white \
        -modifycmd {q [graphed]::update_cb [graphed]::unit_cb} -takefocus 1 \
        -textvariable unit -width 4 
    vTcl:DefineAlias "$site_4_0.cpd135" "UnitBox" vTcl:WidgetProc "Toplevel2" 1
    bindtags $site_4_0.cpd135 "$site_4_0.cpd135 BwComboBox $top all"
    pack $site_4_0.cpd128 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.cpd129 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 5 -side left 
    pack $site_4_0.cpd130 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.cpd131 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 5 -side left 
    pack $site_4_0.cpd132 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.cpd133 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 5 -side left 
    pack $site_4_0.cpd134 \
        -in $site_4_0 -anchor center -expand 0 -fill none -side left 
    pack $site_4_0.cpd135 \
        -in $site_4_0 -anchor center -expand 0 -fill none -padx 5 -side left 
    pack $site_3_0.cpd126 \
        -in $site_3_0 -anchor center -expand 0 -fill x -padx 10 -pady 10 \
        -side top 
    pack $site_3_0.fra127 \
        -in $site_3_0 -anchor center -expand 0 -fill x -padx 10 -side top 
    labelframe $top.lab136 \
        -foreground black -text Scale -highlightcolor black 
    vTcl:DefineAlias "$top.lab136" "Labelframe2" vTcl:WidgetProc "Toplevel2" 1
    set site_3_0 $top.lab136
    checkbutton $site_3_0.che137 \
        -command {q [graphed]::update_cb [graphed]::scale_cb} \
        -font {Helvetica -12} -text {Fit output in x dimension on} \
        -underline 14 -variable scalex 
    vTcl:DefineAlias "$site_3_0.che137" "ScaleXButton" vTcl:WidgetProc "Toplevel2" 1
    SpinBox $site_3_0.spi138 \
        -entrybg white -entryfg black -range {1 100 1} -takefocus 1 -text 0 \
        -textvariable xpages -width 4 
    vTcl:DefineAlias "$site_3_0.spi138" "XPagesBox" vTcl:WidgetProc "Toplevel2" 1
    label $site_3_0.lab139 \
        -font {Helvetica -12} -text page(s) 
    vTcl:DefineAlias "$site_3_0.lab139" "Label7" vTcl:WidgetProc "Toplevel2" 1
    checkbutton $site_3_0.che140 \
        -command {q [graphed]::update_cb [graphed]::scale_cb} \
        -font {Helvetica -12} -text {Fit output in y dimension on} \
        -underline 14 -variable scaley 
    vTcl:DefineAlias "$site_3_0.che140" "ScaleYButton" vTcl:WidgetProc "Toplevel2" 1
    SpinBox $site_3_0.spi141 \
        -entrybg white -entryfg black -range {1 100 1} -takefocus 1 -text 0 \
        -textvariable ypages -width 4 
    vTcl:DefineAlias "$site_3_0.spi141" "YPagesBox" vTcl:WidgetProc "Toplevel2" 1
    label $site_3_0.lab142 \
        -font {Helvetica -12} -text page(s) 
    vTcl:DefineAlias "$site_3_0.lab142" "Label8" vTcl:WidgetProc "Toplevel2" 1
    grid $site_3_0.che137 \
        -in $site_3_0 -column 0 -row 0 -columnspan 1 -rowspan 1 -padx 10 \
        -sticky w 
    grid $site_3_0.spi138 \
        -in $site_3_0 -column 1 -row 0 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_3_0.lab139 \
        -in $site_3_0 -column 2 -row 0 -columnspan 1 -rowspan 1 -padx 10 \
        -sticky w 
    grid $site_3_0.che140 \
        -in $site_3_0 -column 0 -row 1 -columnspan 1 -rowspan 1 -padx 10 \
        -sticky w 
    grid $site_3_0.spi141 \
        -in $site_3_0 -column 1 -row 1 -columnspan 1 -rowspan 1 -sticky w 
    grid $site_3_0.lab142 \
        -in $site_3_0 -column 2 -row 1 -columnspan 1 -rowspan 1 -padx 10 \
        -sticky w 
    frame $top.cpd145 \
        -borderwidth 2 -relief flat -height 85 -width 125 
    vTcl:DefineAlias "$top.cpd145" "Frame4" vTcl:WidgetProc "Toplevel2" 1
    set site_3_0 $top.cpd145
    button $site_3_0.but93 \
        -command {q [graphed]::print_setup_ok_cb} -text Ok -underline 0 \
        -width 6 
    vTcl:DefineAlias "$site_3_0.but93" "PrintSetupOkButton" vTcl:WidgetProc "Toplevel2" 1
    button $site_3_0.but94 \
        -command {q [graphed]::print_setup_cancel_cb} -text Cancel \
        -underline 0 -width 6 
    vTcl:DefineAlias "$site_3_0.but94" "PrintSetupCancelButton" vTcl:WidgetProc "Toplevel2" 1
    pack $site_3_0.but93 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side left 
    pack $site_3_0.but94 \
        -in $site_3_0 -anchor center -expand 0 -fill none -side right 
    ###################
    # SETTING GEOMETRY
    ###################
    pack $top.cpd87 \
        -in $top -anchor center -expand 0 -fill x -ipadx 10 -ipady 5 -padx 10 \
        -pady 10 -side top 
    pack $top.lab125 \
        -in $top -anchor center -expand 0 -fill x -ipadx 10 -ipady 5 -padx 10 \
        -side top 
    pack $top.lab136 \
        -in $top -anchor center -expand 0 -fill x -ipadx 10 -ipady 10 \
        -padx 10 -pady 10 -side top 
    grid columnconf $top.lab136 2 -weight 1
    pack $top.cpd145 \
        -in $top -anchor center -expand 0 -fill x -padx 15 -pady 5 -side top 

    vTcl:FireEvent $base <<Ready>>
}

#############################################################################
## Binding tag:  _TopLevel

bind "_TopLevel" <<Create>> {
    if {![info exists _topcount]} {set _topcount 0}; incr _topcount
}
bind "_TopLevel" <<DeleteWindow>> {
    destroy %W; if {$_topcount == 0} {exit}
}
bind "_TopLevel" <Destroy> {
    if {[winfo toplevel %W] == "%W"} {incr _topcount -1}
}
#############################################################################
## Binding tag:  all

bind "all" <<PrevWindow>> {
    tk::TabToWindow [tk_focusPrev %W]
}
bind "all" <Alt-Key> {
    tk::TraverseToMenu %W %A
}
bind "all" <Key-F10> {
    tk::FirstMenu %W
}
bind "all" <Key-Tab> {
    focus [Widget::focusNext %W]
}
bind "all" <Shift-Key-Tab> {
    focus [Widget::focusPrev %W]
}
#############################################################################
## Binding tag:  _vTclBalloon


if {![info exists vTcl(sourcing)]} {
bind "_vTclBalloon" <<KillBalloon>> {
    namespace eval ::vTcl::balloon {
        after cancel $id
        if {[winfo exists .vTcl.balloon]} {
            destroy .vTcl.balloon
        }
        set set 0
    }
}
bind "_vTclBalloon" <<vTclBalloon>> {
    if {$::vTcl::balloon::first != 1} {break}

    namespace eval ::vTcl::balloon {
        set first 2
        if {![winfo exists .vTcl]} {
            toplevel .vTcl; wm withdraw .vTcl
        }
        if {![winfo exists .vTcl.balloon]} {
            toplevel .vTcl.balloon -bg black
        }
        wm overrideredirect .vTcl.balloon 1
        label .vTcl.balloon.l  -text ${%W} -relief flat  -bg #ffffaa -fg black -padx 2 -pady 0 -anchor w
        pack .vTcl.balloon.l -side left -padx 1 -pady 1
        wm geometry  .vTcl.balloon  +[expr {[winfo rootx %W]+[winfo width %W]/2}]+[expr {[winfo rooty %W]+[winfo height %W]+4}]
        set set 1
    }
}
bind "_vTclBalloon" <Button> {
    namespace eval ::vTcl::balloon {
        set first 0
    }
    vTcl:FireEvent %W <<KillBalloon>>
}
bind "_vTclBalloon" <Enter> {
    namespace eval ::vTcl::balloon {
        ## self defining balloon?
        if {![info exists %W]} {
            vTcl:FireEvent %W <<SetBalloon>>
        }
        set set 0
        set first 1
        set id [after 500 {vTcl:FireEvent %W <<vTclBalloon>>}]
    }
}
bind "_vTclBalloon" <Leave> {
    namespace eval ::vTcl::balloon {
        set first 0
    }
    vTcl:FireEvent %W <<KillBalloon>>
}
bind "_vTclBalloon" <Motion> {
    namespace eval ::vTcl::balloon {
        if {!$set} {
            after cancel $id
            set id [after 500 {vTcl:FireEvent %W <<vTclBalloon>>}]
        }
    }
}
}
#############################################################################
## Binding tag:  TopLevel1

bind "TopLevel1" <Key-Control_L> {
    # TODO: your event handler here
global lctrl; set lctrl 1
q [graphed]::mod_cb
}
bind "TopLevel1" <Key-Control_R> {
    # TODO: your event handler here
global rctrl; set rctrl 1
q [graphed]::mod_cb
}
bind "TopLevel1" <Key-Shift_L> {
    # TODO: your event handler here
global lshift; set lshift 1
q [graphed]::mod_cb
}
bind "TopLevel1" <Key-Shift_R> {
    # TODO: your event handler here
global rshift; set rshift 1
q [graphed]::mod_cb
}
bind "TopLevel1" <KeyRelease-Control_L> {
    # TODO: your event handler here
global lctrl; set lctrl 0
q [graphed]::mod_cb
}
bind "TopLevel1" <KeyRelease-Control_R> {
    # TODO: your event handler here
global rctrl; set rctrl 0
q [graphed]::mod_cb
}
bind "TopLevel1" <KeyRelease-Shift_L> {
    # TODO: your event handler here
global lshift; set lshift 0
q [graphed]::mod_cb
}
bind "TopLevel1" <KeyRelease-Shift_R> {
    # TODO: your event handler here
global rshift; set rshift 0
q [graphed]::mod_cb
}

Window show .
Window show .top81
Window show .top83
Window show .top84

main $argc $argv
